@@ -1,6 +1,7 @@
 import os, sys
 import markdown2
 import re
+from collections import OrderedDict
 try:
     curr_path = os.path.dirname(os.path.abspath(__file__))
     teedoc_project_path = os.path.abspath(os.path.join(curr_path, "..", "..", ".."))
@@ -14,7 +15,7 @@ from teedoc import Fake_Logger
 
 
 class Plugin(Plugin_Base):
-    name = "markdown-parser"
+    name = "teedoc-plugin-markdown-parser"
     desc = "markdown parser plugin for teedoc"
     defautl_config = {
         "parse_files": ["md"]
@@ -32,21 +33,22 @@ class Plugin(Plugin_Base):
         self.config.update(config)
         self.logger.i("-- plugin <{}> init".format(self.name))
         self.logger.i("-- plugin <{}> config: {}".format(self.name, self.config))
-        self._extention = [
-            "toc",
-            "metadata",
-            "fenced-code-blocks",
-            "highlightjs-lang",
-            "break-on-newline",
-            "code-friendly",
-            "cuddled-lists",
-            "footnotes",
-            "strike",
-            "spoiler",
-            "tables",
-            "task_list"
-        ]
-        self.parser = markdown2.Markdown(extras = self._extention)
+        self._extention = {
+            "toc" : {
+                "depth": config["toc_depth"] if "toc_depth" in config else 3
+            },
+            "metadata" : None,
+            "fenced-code-blocks" : None,
+            "highlightjs-lang" : None,
+            "break-on-newline" : None,
+            "code-friendly" : None,
+            "cuddled-lists" : None,
+            "footnotes" : None,
+            "strike" : None,
+            "spoiler" : None,
+            "tables" : None,
+            "task_list" : None
+        }
         
 
     def on_parse_files(self, files):
@@ -54,7 +56,7 @@ class Plugin(Plugin_Base):
         result = {
             "ok": False,
             "msg": "",
-            "htmls": {}
+            "htmls": OrderedDict()
         }
         # function parse md file is disabled
         if not "md" in self.config["parse_files"]:
@@ -69,8 +71,9 @@ class Plugin(Plugin_Base):
                 with open(file, encoding="utf-8") as f:
                     content = f.read().strip()
                     content = self._update_link(content)
-                    self.parser._toc_html = ""
-                    html = self.parser.convert(content)
+                    parser = markdown2.Markdown(extras = self._extention)
+                    parser._toc_html = ""
+                    html = parser.convert(content)
                     if "title" in html.metadata:
                         title = html.metadata["title"]
                     else:
@@ -94,7 +97,8 @@ class Plugin(Plugin_Base):
                         "tags": tags,
                         "body": html,
                         "toc": html.toc_html if html.toc_html else "",
-                        "metadata": html.metadata
+                        "metadata": html.metadata,
+                        "raw": content
                     }
             else:
                 result["htmls"][file] = None
@@ -102,9 +106,7 @@ class Plugin(Plugin_Base):
         return result
     
     def on_parse_pages(self, files):
-        print(files)
         result = self.on_parse_files(files)
-        print(result)
         return result
 
     
